@@ -161,7 +161,7 @@ mod tests {
             default: None,
             location: Path::new(DEFAULT_LOCATION).to_owned(),
             user: DEFAULT_USER.to_owned(),
-            command_prefix: "".to_owned(),
+            command_prefix: String::new(),
             tasks,
         }
     }
@@ -176,7 +176,7 @@ mod tests {
             default: None,
             location: Path::new(DEFAULT_LOCATION).to_owned(),
             user: DEFAULT_USER.to_owned(),
-            command_prefix: "".to_owned(),
+            command_prefix: String::new(),
             tasks,
         }
     }
